@@ -1,7 +1,10 @@
-package # hide from PAUSE 
+package # hide from PAUSE
     DBICTest::Schema::Lyrics;
 
-use base qw/DBIx::Class::Core/;
+use warnings;
+use strict;
+
+use base qw/DBICTest::BaseResult/;
 
 __PACKAGE__->table('lyrics');
 __PACKAGE__->add_columns(
